============
Installation
============

At the command line::

    pip install pyncette

For installing with Redis peristence::

    pip install pyncette[redis]

For installing with PostgreSQL peristence::

    pip install pyncette[postgres]

For installing with Prometheus metrics exporter::

    pip install pyncette[prometheus]